<img
	src="https://cdn.yourpng.com/uploads/preview/pink-welcome-word-png-transparent-background-11622180582ept25roftu.png"
	style="width: 100%"
	>
</img>

# Introduction

This software uses the markdown syntax, you can read more about it on [this webpage](https://daringfireball.net/projects/markdown/syntax) and many more.

## List of extended syntaxes

### tables

| title1 | title2 |
| ------ | ------ |
| item 1 | item X |
| apple  | pear   |

```
| title1 | title2 |
|------|-----|
| item 1 | item X |
| apple | pear |
```

### self links

[[Other page name]]

```markdown
\[[Other page name]]
```

### check lists

- [ ] todo
- [x] done

```markdown
- [ ] todo
- [x] done
```

### Definitions

Some term
: and the definition

### inserted text

There is ++some insertion++ in this text

```
There is ++some insertion++ in this text
```

### Abbreviations

*[HTML]: Hyper Text Markup Language
*[W3C]: World Wide Web Consortium
The HTML specification
is maintained by the W3C.

```
*[HTML]: Hyper Text Markup Language
*[W3C]:  World Wide Web Consortium

The HTML specification
is maintained by the W3C.
```

### Emoji

LOL ;) This is funny :P
Search for "github emoji" to find the list :heart:

```
LOL ;) This is funny :P
Search for "github emoji" to find the list :heart:
```

### Calendar


#calendar(
2/11/2021 13:30-15:30 Test appointment
@yearly 18/8/1982  8:00-18:00 Birthday John
    @weekly 4/11/2021 8:00-18:00  Swimming pool
)

**DO NOT put a space after the initial "#" while using this feature:**

```
# calendar(
2/11/2021 13:30-15:30 Test appointment
@yearly 18/8/1982  8:00-18:00 Birthday John
@weekly 4/11/2021 8:00-18:00  Swimming pool
)
```
